@@ -270,9 +270,23 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE);
     MAKE_SIGNAL(NV_CTRL_GVO_ENABLE_RGB_DATA);
     MAKE_SIGNAL(NV_CTRL_IMAGE_SHARPENING_DEFAULT);
-    MAKE_SIGNAL(NV_CTRL_GVI_NUM_PORTS);
+    MAKE_SIGNAL(NV_CTRL_GVI_NUM_JACKS);
+    MAKE_SIGNAL(NV_CTRL_GVI_MAX_LINKS_PER_STREAM);
+    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_BITS_PER_COMPONENT);
+    MAKE_SIGNAL(NV_CTRL_GVI_REQUESTED_STREAM_BITS_PER_COMPONENT);
+    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_COMPONENT_SAMPLING);
+    MAKE_SIGNAL(NV_CTRL_GVI_REQUESTED_STREAM_COMPONENT_SAMPLING);
+    MAKE_SIGNAL(NV_CTRL_GVI_REQUESTED_STREAM_CHROMA_EXPAND);
+    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_COLOR_SPACE);
+    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_LINK_ID);
+    MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_SMPTE352_IDENTIFIER);
+    MAKE_SIGNAL(NV_CTRL_GVI_GLOBAL_IDENTIFIER);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION);
     MAKE_SIGNAL(NV_CTRL_GPU_POWER_MIZER_MODE);
+    MAKE_SIGNAL(NV_CTRL_GVI_SYNC_OUTPUT_FORMAT);
+    MAKE_SIGNAL(NV_CTRL_GVI_MAX_CHANNELS_PER_JACK);
+    MAKE_SIGNAL(NV_CTRL_GVI_MAX_STREAMS);
+    MAKE_SIGNAL(NV_CTRL_GVI_NUM_CAPTURE_SURFACES);
 
 #undef MAKE_SIGNAL
     
@@ -283,7 +297,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
      * knows about.
      */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_GPU_POWER_MIZER_MODE
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_GVI_NUM_CAPTURE_SURFACES
 #warning "There are attributes that do not emit signals!"
 #endif
 
